@@ -27,8 +27,5 @@ class Dump(Node):
 
     def update(self):
         if self.i.ready():
-            self.i.data["index"] = self.i.data.index
-            self.i.data["index"] = pd.to_timedelta(
-                self.i.data["index"]
-            ).dt.total_seconds()
+            self.i.data["index"] = self.i.data.index.values.astype("float64") / 1e9
             self.writer.writerows(self.i.data.values.tolist())
